# Processamento de Imagens :framed_picture: 

## Bootcamp DIO - Unimed/BH

#### Capitulo 02 - Python - 

Descrição / Description :

O pacote IMAGE-PROCESSING-PACK é utilizado para: 

- **Módulo processing:**
  - Correspondencia de histograma
  - Similaridade estrutural;
  - Redimensionamento da imagem
- **Módulo utils:**
  - Ler imagem
  - Salvar imagem
  - Plotar imagem
  - Resultado do gráfico
  - Plotar histograma



Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_name

```bash
pip install IMAGE_PROCESSING_PACK
```



## Author
"Gilcimar Gomes"

## License
[MIT](https://choosealicense.com/licenses/mit/)